==> haskell-x509-1.7.7-59-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-x509.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 x509
version:              1.7.7
visibility:           public
id:                   x509-1.7.7-3QC6qoOkCVk9C9NmT3v47w
key:                  x509-1.7.7-3QC6qoOkCVk9C9NmT3v47w
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             http://github.com/vincenthz/hs-certificate
synopsis:             X509 reader and writer
description:          X509 reader and writer. please see README
category:             Data
abi:                  dabfdc1fa5eebc7021e2864619b39dd1
exposed:              True
exposed-modules:      Data.X509 Data.X509.EC
hidden-modules:
    Data.X509.Internal Data.X509.CertificateChain
    Data.X509.AlgorithmIdentifier Data.X509.DistinguishedName
    Data.X509.Cert Data.X509.PublicKey Data.X509.PrivateKey
    Data.X509.Ext Data.X509.ExtensionRaw Data.X509.CRL Data.X509.OID
    Data.X509.Signed

import-dirs:          /usr/lib/ghc-9.2.8/site-local/x509-1.7.7
library-dirs:         /usr/lib/ghc-9.2.8/site-local/x509-1.7.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-x509
hs-libraries:         HSx509-1.7.7-3QC6qoOkCVk9C9NmT3v47w
depends:
    asn1-encoding-0.9.6-IkosapRt3AP5MNPOrKN0lm
    asn1-parse-0.9.5-DP5KRx0HAAV721G82sH5pM
    asn1-types-0.3.4-Hyn5kZFolX7gxDa6hTx8x base-4.16.4.0
    bytestring-0.11.4.0 containers-0.6.5.1
    cryptonite-0.30-B8lqKo2bgZjIAiaKsp19j7
    hourglass-0.2.12-IgEtyVcSREg9suG8D80qmq
    memory-0.18.0-Hvum6HaH78UJG59LYyNLK1
    pem-0.2.4-5N4eCpXQrJA1x0C3DKrXBd transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-x509/html/x509.haddock
haddock-html:         /usr/share/doc/haskell-x509/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-x509-1.7.7-61-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-x509.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 x509
version:              1.7.7
visibility:           public
id:                   x509-1.7.7-7PZAm7Ehoul7ooBkMn84C7
key:                  x509-1.7.7-7PZAm7Ehoul7ooBkMn84C7
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             http://github.com/vincenthz/hs-certificate
synopsis:             X509 reader and writer
description:          X509 reader and writer. please see README
category:             Data
abi:                  f80abd03e72bda62afb71222b1c67aef
exposed:              True
exposed-modules:      Data.X509 Data.X509.EC
hidden-modules:
    Data.X509.Internal Data.X509.CertificateChain
    Data.X509.AlgorithmIdentifier Data.X509.DistinguishedName
    Data.X509.Cert Data.X509.PublicKey Data.X509.PrivateKey
    Data.X509.Ext Data.X509.ExtensionRaw Data.X509.CRL Data.X509.OID
    Data.X509.Signed

import-dirs:          /usr/lib/ghc-9.2.8/site-local/x509-1.7.7
library-dirs:         /usr/lib/ghc-9.2.8/site-local/x509-1.7.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-x509
hs-libraries:         HSx509-1.7.7-7PZAm7Ehoul7ooBkMn84C7
depends:
    asn1-encoding-0.9.6-6GqwFFmrDK82IsCOUk2PEt
    asn1-parse-0.9.5-96hM1zKuSre6t8y4I3gFvC
    asn1-types-0.3.4-Jw71wui5Ob54LqM1Y0htWU base-4.16.4.0
    bytestring-0.11.4.0 containers-0.6.5.1
    cryptonite-0.30-7YCFiEak3iS4jVbhqnIKep
    hourglass-0.2.12-AqgCZcM6ZmxAi8T3YvbuVc
    memory-0.18.0-Hvum6HaH78UJG59LYyNLK1
    pem-0.2.4-DcNj6eIVIfzGJuAlSYXCHc transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-x509/html/x509.haddock
haddock-html:         /usr/share/doc/haskell-x509/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
